-- *************************************
-- Use Replace to change the following two items
-- (1) Replace <DB> with the name of the database to create
--	usually: change <DB> to PetStore   (remove the brackets)
-- (2) Replace <PATH> with the full path to this file
--	example: change <PATH> to C:\Temp\Bakery\
-- *************************************

IF NOT EXISTS (SELECT * FROM sys.databases
	WHERE name = N'<DB>')
	CREATE DATABASE <DB>
GO
USE <DB>
--
-- Create the path to the CSV files
--
DECLARE @data_path nvarchar(256);
SELECT @data_path = '<PATH>';
--

-- *************************************
-- Drop existing tables
-- *************************************

IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'EconData')
   drop table EconData;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'SaleItem')
  drop table SaleItem;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Sale')
  drop table Sale;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Product')
  drop table Product;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'ProductCategory')
  drop table ProductCategory;
--

-- *************************************
-- Create the tables
-- *************************************

CREATE TABLE ProductCategory
(  CategoryID	int NOT NULL,
   Category		nvarchar(100) NULL,
   Preference	float NULL,
   CONSTRAINT pk_ProductCategory PRIMARY KEY (CategoryID)
)
;

CREATE TABLE Product
(  ProductID	int NOT NULL,
   CategoryID	int NOT NULL,
   ProductName	nvarchar(200) NULL,
   [Size]		nvarchar(100) NULL,
   [Description] nvarchar(250) NULL,
   ListPrice	money NULL,
   Preference	float NULL,
   ListPriceBase money NULL,
   SelectionCDF	float NULL,
	CONSTRAINT pk_Product PRIMARY KEY (ProductID),
	CONSTRAINT fk_Product_ProductCategory FOREIGN KEY (CategoryID)
		REFERENCES ProductCategory (CategoryID)
		ON DELETE CASCADE
);

CREATE TABLE Sale
(  SaleID	int NOT NULL,
   SaleDate	datetime NULL,
	CONSTRAINT pk_Sale PRIMARY KEY (SaleID)
);

CREATE TABLE SaleItem
(  SaleID		int NOT NULL,
   ProductID	int NOT NULL,
   Quantity		int NULL,
   SalePrice	money NULL,
   Seq		int NULL,
	CONSTRAINT pk_SaleItem PRIMARY KEY (SaleID, ProductID),
	CONSTRAINT fk_SaleItem_Sale FOREIGN KEY (SaleID)
		REFERENCES Sale (SaleID)
		ON DELETE CASCADE,
	CONSTRAINT fk_SaleItem_Product FOREIGN KEY (ProductID)
		REFERENCES Product (ProductID)
		ON DELETE CASCADE
)	   

CREATE TABLE EconData
( YearMonth	int NOT NULL,
  DPI		float NULL,
  CPI		float NULL,
	CONSTRAINT pk_EconData PRIMARY KEY (YearMonth)
)

--
-- *************************************
-- Load table data
-- *************************************
--
EXECUTE (N'BULK INSERT ProductCategory FROM ''' + @data_path + N'ProductCategory.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Product FROM ''' + @data_path + N'Product.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
EXECUTE (N'BULK INSERT Sale FROM ''' + @data_path + N'Sale.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
EXECUTE (N'BULK INSERT SaleItem FROM ''' + @data_path + N'SaleItem.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
EXECUTE (N'BULK INSERT EconData FROM ''' + @data_path + N'EconData.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- ********************
-- List table names and row counts
-- ********************
GO
SET NOCOUNT ON
SELECT 'ProductCategory' "Table", Count(*) "Rows" FROM Product UNION
SELECT 'Product',                 Count(*) FROM Product        UNION
SELECT 'Sale',                    Count(*) FROM Sale           UNION
SELECT 'SaleItem',                Count(*) FROM SaleItem       UNION
SELECT 'EconData',                Count(*) FROM EconData  
ORDER BY 1;
SET NOCOUNT OFF
Go

